from ftransc.metadata.metadata import Metadata

__all__ = [
    'Metadata',
]
